@@ -2,7 +2,7 @@
 //
 //    CDARCHIVING.H
 //
-//    Copyright (C) 2003-2004 Gilles Caulier <caulier dot gilles at free.fr>
+//    Copyright (C) 2003-2004 Gilles Caulier <caulier dot gilles at gmail dot com>
 //    Copyright (C) 2003-2004 by Gregory Kokanosky <gregory dot kokanosky at free.fr>
 //    for images navigation mode.
 //
@@ -18,7 +18,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -152,6 +152,7 @@ private:
   
   QObject            *m_parent;
   
+  QStringList        m_collection_name_list;
 private:
   
   bool buildHTMLInterface (void);
@@ -166,7 +167,7 @@ private:
                   const KURL& targetURL,
                   const QString& imageFormat);
 
-  int  createThumb( const QString& imgName, const QString& sourceDirName,
+  int  createThumb( const QString& imgName, const QString& sourceDirName, const QString& uniqueFileName,
                     const QString& imgGalleryDir, const QString& imageFormat);
 
   int  ResizeImage( const QString Path, const QString Directory, const QString ImageFormat,
@@ -179,8 +180,11 @@ private:
 
   bool createPage(const QString& imgGalleryDir,
                   const KURL& imgURL,
+                  const QString& uniqueImgName,
                   const KURL& prevImgURL,
+                  const QString& prevUniqueImgName,
                   const KURL& nextImgURL,
+                  const QString& nextUniqueImgName,
                   const QString& comment);
 
   void createBodyMainPage(QTextStream& stream, KURL& url);
@@ -203,6 +207,8 @@ private:
   void readSettings(void);
 
   QString webifyFileName(QString fileName);
+  QString makeFileNameUnique(QStringList& list, QString fileName);
+
 };
 
 }  // NameSpace KIPICDArchivingPlugin
