@@ -75,7 +75,7 @@ namespace KIPIFindDupplicateImagesPlugin
 
 FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, QWidget *parent)
                    : KDialogBase( IconList, i18n("Configure"), Help|Ok|Cancel,
-                                  Ok, parent, "FindDuplicateDialog", true, true ),
+                                  Ok, parent, "FindDuplicateDialog", true, false ),
                                   m_interface( interface )
 {
     setCaption(i18n("Find Duplicate Images"));
@@ -87,7 +87,7 @@ FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, QWidget *p
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Find Duplicate Images"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to find duplicate images\n"
                                                      "This plugin is based on ShowImg implementation algorithm"),
@@ -105,7 +105,7 @@ FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, QWidget *p
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Find Duplicate Images Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 }
 
