@@ -16,7 +16,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -56,7 +56,7 @@ Plugin_Imagesgallery::Plugin_Imagesgallery(QObject *parent, const char*, const Q
 void Plugin_Imagesgallery::setup( QWidget* widget )
 {
     KIPI::Plugin::setup( widget );
-    m_actionImagesGallery = new KAction (i18n("HTML Export..."),        // Menu message.
+    m_actionImagesGallery = new KAction (i18n("Images Gallery..."),     // Menu message.
                                          "www",                         // Menu icon.
                                          0,
                                          this,
