@@ -6,7 +6,12 @@
  * Date        : 2003-10-14
  * Description : batch image flip
  *
- * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2007 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * NOTE: Do not use kdDebug() in this implementation because 
+ *       it will be multithreaded. Use qDebug() instead. 
+ *       See B.K.O #133026 for details.
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,8 +51,8 @@ extern "C"
 
 #include <kprocess.h>
 #include <klocale.h>
-#include <kdebug.h>
 #include <kurl.h>
+#include <ktempfile.h>
 
 // Local includes
 
@@ -63,29 +68,38 @@ namespace KIPIJPEGLossLessPlugin
 ImageFlip::ImageFlip()
          : QObject()
 {
+    m_tmpFile = new KTempFile(QString(), QString("kipiplugin-flip"));
+    m_tmpFile->setAutoDelete(true);
 }
 
 ImageFlip::~ImageFlip()
 {
+    delete m_tmpFile;
 }
 
-bool ImageFlip::flip(const QString& src, FlipAction action, const QString& TmpFolder, QString& err)
+bool ImageFlip::flip(const QString& src, FlipAction action, QString& err)
 {
     QFileInfo fi(src);
+
     if (!fi.exists() || !fi.isReadable() || !fi.isWritable()) 
     {
         err = i18n("Error in opening input file");
         return false;
     }
 
-    /* Generate temporary filename */
-    QString tmp = TmpFolder + "imageflip-" + fi.fileName();
+    if ( !m_tmpFile->file() )
+    {
+        err = i18n("Error in opening temporary file");
+        return false;
+    }
+
+    QString tmp = m_tmpFile->name();
 
     if (Utils::isRAW(src))
     {
         err = i18n("Cannot rotate RAW file");
         return false;
-    }    
+    }
     else if (Utils::isJPEG(src))
     {
         if (!flipJPEG(src, tmp, action, err))
@@ -97,6 +111,11 @@ bool ImageFlip::flip(const QString& src, FlipAction action, const QString& TmpFo
         // else TIFF/PNG 16 bits image are broken!
         if (!flipImageMagick(src, tmp, action, err))
             return false;
+
+        // We update metadata on new image.
+        Utils tools(this);
+        if (!tools.updateMetadataImageMagick(tmp, err))
+            return false;
     }
 
     // Move back to original file
@@ -127,7 +146,7 @@ bool ImageFlip::flipJPEG(const QString& src, const QString& dest, FlipAction act
         }
         default:
         {
-            kdError( 51000 ) << "ImageFlip: Nonstandard flip action" << endl;
+            qDebug("ImageFlip: Nonstandard flip action");
             err = i18n("Nonstandard flip action");
             return false;
         }
@@ -140,7 +159,8 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
 {
     KProcess process;
     process.clearArguments();
-    process << "convert";    
+    process << "convert";
+    process << "-verbose";
 
     switch(action)
     {
@@ -156,7 +176,7 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
         }
         default:
         {
-            kdError() << "ImageFlip: Nonstandard flip action" << endl;
+            qDebug("ImageFlip: Nonstandard flip action");
             err = i18n("Nonstandard flip action");
             return false;
         }
@@ -164,7 +184,10 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
 
     process << src + QString("[0]") << dest;
 
-    kdDebug( 51000 ) << "ImageMagick Command line: " << process.args() << endl;    
+    qDebug("ImageMagick Command line args:");
+    QValueList<QCString> args = process.args();
+    for (QValueList<QCString>::iterator it = args.begin(); it != args.end(); ++it)
+        qDebug("%s", (const char*)(*it));
 
     connect(&process, SIGNAL(receivedStderr(KProcess *, char*, int)),
             this, SLOT(slotReadStderr(KProcess*, char*, int)));
@@ -172,6 +195,9 @@ bool ImageFlip::flipImageMagick(const QString& src, const QString& dest, FlipAct
     if (!process.start(KProcess::Block, KProcess::Stderr))
         return false;
 
+    if (!process.normalExit())
+        return false;
+
     switch (process.exitStatus())
     {
         case 0:  // Process finished successfully !
