@@ -7,6 +7,7 @@
  * Description : batch image rotation
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2004-2007 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -31,9 +32,9 @@
 // Qt includes.
 
 #include <qobject.h>
+#include <qstring.h>
 
-class QString;
-
+class KTempFile;
 class KProcess;
 
 namespace KIPIJPEGLossLessPlugin
@@ -48,7 +49,7 @@ public:
     ImageRotate();
     ~ImageRotate();
 
-    bool rotate(const QString& src, RotateAction angle, const QString& TmpFolder, QString& err);
+    bool rotate(const QString& src, RotateAction angle, QString& err);
 
 private slots:
 
@@ -57,12 +58,13 @@ private slots:
 private:
 
     bool rotateJPEG(const QString& src, const QString& dest, RotateAction angle, QString& err);
-    
     bool rotateImageMagick(const QString& src, const QString& dest, RotateAction angle, QString& err);
 
 private:
 
-    QString m_stdErr;
+    QString    m_stdErr;
+
+    KTempFile *m_tmpFile;
 };
 
 }  // NameSpace KIPIJPEGLossLessPlugin
