@@ -1,23 +1,24 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date  : 2003-10-24
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // C Ansi includes.
@@ -29,6 +30,10 @@ extern "C"
 #include <unistd.h>
 }
 
+// C++ includes.
+
+#include <cstdio> 
+
 // Qt includes.
 
 #include <qframe.h>
@@ -59,12 +64,15 @@ extern "C"
 #include <kpopupmenu.h>
 #include <kstandarddirs.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawsettingswidget.h>
+
 // Local includes.
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-#include "dcrawiface.h"
-#include "dcrawsettingswidget.h"
+#include "rawdecodingiface.h"
 #include "savesettingswidget.h"
 #include "actionthread.h"
 #include "clistviewitem.h"
@@ -74,7 +82,7 @@ extern "C"
 namespace KIPIRawConverterPlugin
 {
 
-BatchDialog::BatchDialog(QWidget* /*parent*/, const QString& dcrawVersion)
+BatchDialog::BatchDialog(QWidget* /*parent*/)
            : KDialogBase(0, 0, false, i18n("Raw Images Batch Converter"),
                          Help|Default|User1|User2|Close, Close, true,
                          i18n("Con&vert"), i18n("&Abort"))
@@ -83,33 +91,10 @@ BatchDialog::BatchDialog(QWidget* /*parent*/, const QString& dcrawVersion)
     m_thread             = 0;
     m_page = new QWidget( this );
     setMainWidget( m_page );
-    QGridLayout *mainLayout = new QGridLayout(m_page, 5, 1, 0, marginHint());
+    QGridLayout *mainLayout = new QGridLayout(m_page, 2, 1, 0, spacingHint());
 
     //---------------------------------------------
 
-    QFrame *headerFrame = new QFrame( m_page );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Raw Images Batch Converter"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    mainLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    // --------------------------------------------------------------
-
     m_listView = new KListView(m_page);
     m_listView->addColumn( i18n("Thumbnail") );
     m_listView->addColumn( i18n("Raw File") );
@@ -121,53 +106,48 @@ BatchDialog::BatchDialog(QWidget* /*parent*/, const QString& dcrawVersion)
     m_listView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_listView->setSelectionMode(QListView::Single);
     m_listView->setMinimumWidth(450);
-    mainLayout->addMultiCellWidget(m_listView, 1, 5, 0, 0);
 
     // ---------------------------------------------------------------
 
-    m_decodingSettingsBox = new DcrawSettingsWidget(m_page, dcrawVersion);
+    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(m_page, false, true, true);
     m_saveSettingsBox     = new SaveSettingsWidget(m_page);
-
-    mainLayout->addMultiCellWidget(m_decodingSettingsBox, 1, 1, 1, 1);
-    mainLayout->addMultiCellWidget(m_saveSettingsBox, 2, 3, 1, 1);
+    m_decodingSettingsBox->insertTab(m_saveSettingsBox, i18n("Save settings"));
 
     m_progressBar = new KProgress(m_page);
-    m_progressBar->setMaximumHeight( fontMetrics().height() );
-    m_progressBar->setEnabled(false);
-    mainLayout->addMultiCellWidget(m_progressBar, 4, 4, 1, 1);
+    m_progressBar->setMaximumHeight( fontMetrics().height()+2 );
+    m_progressBar->hide();
 
+    mainLayout->addMultiCellWidget(m_listView, 0, 2, 0, 0);
+    mainLayout->addMultiCellWidget(m_decodingSettingsBox, 0, 0, 1, 1);
+    mainLayout->addMultiCellWidget(m_progressBar, 1, 1, 1, 1);
     mainLayout->setColStretch(0, 10);
-    mainLayout->setRowStretch(5, 10);
+    mainLayout->setRowStretch(2, 10);
 
     // ---------------------------------------------------------------
     // About data and help button.
 
-    QPushButton *helpButton = actionButton( Help );
-
-    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Raw Images Batch Converter"),
-                                           NULL,
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
+                                           0,
                                            KAboutData::License_GPL,
-                                           I18N_NOOP("A Kipi plugin for Raw images conversion\n"
-                                                     "This plugin uses the Dave Coffin Raw photo "
-                                                     "decoder program \"dcraw\""),
+                                           I18N_NOOP("A Kipi plugin to batch convert Raw images"),
                                            "(c) 2003-2005, Renchi Raju\n"
-                                           "(c) 2006, Gilles Caulier");
+                                           "(c) 2006-2008, Gilles Caulier");
 
     m_about->addAuthor("Renchi Raju", I18N_NOOP("Original author"),
-                       "renchi@pooh.tam.uiuc.edu");
+                       "renchi at pooh dot tam dot uiuc dot edu");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Maintainer"),
-                       "caulier dot gilles at kdemail dot net");
+                       "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Raw Converter Handbook"),
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
                                  this, SLOT(slotHelp()), 0, -1, 0);
-    helpButton->setPopup( helpMenu->menu() );
+    actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
 
-    setButtonTip( User1, i18n("<p>Start converting the raw images from current settings"));
+    setButtonTip( User1, i18n("<p>Start converting the Raw images from current settings"));
     setButtonTip( User2, i18n("<p>Abort the current Raw files conversion"));
     setButtonTip( Close, i18n("<p>Exit Raw Converter"));
 
@@ -223,27 +203,34 @@ void BatchDialog::readSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    m_decodingSettingsBox->setCameraWB(config.readBoolEntry("Use Camera WB", true));
-    m_decodingSettingsBox->setAutoColorBalance(config.readBoolEntry("Use Auto Color Balance", true));
+    m_decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
+                                            config.readNumEntry("White Balance",
+                                            KDcrawIface::RawDecodingSettings::CAMERA));
+    m_decodingSettingsBox->setCustomWhiteBalance(config.readNumEntry("Custom White Balance", 6500));
+    m_decodingSettingsBox->setCustomWhiteBalanceGreen(config.readDoubleNumEntry("Custom White Balance Green", 1.0));
     m_decodingSettingsBox->setFourColor(config.readBoolEntry("Four Color RGB", false));
     m_decodingSettingsBox->setUnclipColor(config.readNumEntry("Unclip Color", 0));
-    m_decodingSettingsBox->setSecondarySensor(config.readBoolEntry("Use Secondary Sensor", false));
-    m_decodingSettingsBox->setNoiseReduction(config.readBoolEntry("Use Noise Resuction", false));
+    m_decodingSettingsBox->setDontStretchPixels(config.readBoolEntry("Dont Stretch Pixels", false));
+    m_decodingSettingsBox->setNoiseReduction(config.readBoolEntry("Use Noise Reduction", false));
     m_decodingSettingsBox->setBrightness(config.readDoubleNumEntry("Brightness Multiplier", 1.0));
-    m_decodingSettingsBox->setSigmaDomain(config.readDoubleNumEntry("Sigma Domain", 2.0));
-    m_decodingSettingsBox->setSigmaRange(config.readDoubleNumEntry("Sigma Range", 4.0));
+    m_decodingSettingsBox->setUseBlackPoint(config.readBoolEntry("Use Black Point", false));
+    m_decodingSettingsBox->setBlackPoint(config.readNumEntry("Black Point", 0));
+    m_decodingSettingsBox->setNRThreshold(config.readNumEntry("NR Threshold", 100));
+    m_decodingSettingsBox->setUseCACorrection(config.readBoolEntry("EnableCACorrection", false));
+    m_decodingSettingsBox->setcaRedMultiplier(config.readDoubleNumEntry("caRedMultiplier", 1.0));
+    m_decodingSettingsBox->setcaBlueMultiplier(config.readDoubleNumEntry("caBlueMultiplier", 1.0));
 
     m_decodingSettingsBox->setQuality(
-        (RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
-            (int)(RawDecodingSettings::BILINEAR))); 
+        (KDcrawIface::RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
+            (int)(KDcrawIface::RawDecodingSettings::BILINEAR))); 
 
     m_decodingSettingsBox->setOutputColorSpace(
-        (RawDecodingSettings::OutputColorSpace)config.readNumEntry("Output Color Space", 
-            (int)(RawDecodingSettings::SRGB))); 
+        (KDcrawIface::RawDecodingSettings::OutputColorSpace)config.readNumEntry("Output Color Space", 
+            (int)(KDcrawIface::RawDecodingSettings::SRGB))); 
 
     m_saveSettingsBox->setFileFormat(
-        (RawDecodingSettings::OutputFormat)config.readNumEntry("Output Format", 
-            (int)(RawDecodingSettings::PNG))); 
+        (SaveSettingsWidget::OutputFormat)config.readNumEntry("Output Format", 
+            (int)(SaveSettingsWidget::OUTPUT_PNG))); 
 
     m_saveSettingsBox->setConflictRule(
         (SaveSettingsWidget::ConflictRule)config.readNumEntry("Conflict",
@@ -257,15 +244,20 @@ void BatchDialog::saveSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    config.writeEntry("Use Camera WB", m_decodingSettingsBox->useCameraWB());
-    config.writeEntry("Use Auto Color Balance", m_decodingSettingsBox->useAutoColorBalance());
+    config.writeEntry("White Balance", m_decodingSettingsBox->whiteBalance());
+    config.writeEntry("Custom White Balance", m_decodingSettingsBox->customWhiteBalance());
+    config.writeEntry("Custom White Balance Green", m_decodingSettingsBox->customWhiteBalanceGreen());
     config.writeEntry("Four Color RGB", m_decodingSettingsBox->useFourColor());
     config.writeEntry("Unclip Color", m_decodingSettingsBox->unclipColor());
-    config.writeEntry("Use Secondary Sensor", m_decodingSettingsBox->useSecondarySensor());
-    config.writeEntry("Use Noise Resuction", m_decodingSettingsBox->useNoiseReduction());
+    config.writeEntry("Dont Stretch Pixels", m_decodingSettingsBox->useDontStretchPixels());
+    config.writeEntry("Use Noise Reduction", m_decodingSettingsBox->useNoiseReduction());
     config.writeEntry("Brightness Multiplier", m_decodingSettingsBox->brightness());
-    config.writeEntry("Sigma Domain", m_decodingSettingsBox->sigmaDomain());
-    config.writeEntry("Sigma Range", m_decodingSettingsBox->sigmaRange());
+    config.writeEntry("Use Black Point", m_decodingSettingsBox->useBlackPoint());
+    config.writeEntry("Black Point", m_decodingSettingsBox->blackPoint());
+    config.writeEntry("NR Threshold", m_decodingSettingsBox->NRThreshold());
+    config.writeEntry("EnableCACorrection", m_decodingSettingsBox->useCACorrection());
+    config.writeEntry("caRedMultiplier", m_decodingSettingsBox->caRedMultiplier());
+    config.writeEntry("caBlueMultiplier", m_decodingSettingsBox->caBlueMultiplier());
     config.writeEntry("Decoding Quality", (int)m_decodingSettingsBox->quality());
     config.writeEntry("Output Color Space", (int)m_decodingSettingsBox->outputColorSpace());
 
@@ -307,23 +299,27 @@ void BatchDialog::slotUser1()
 
     m_progressBar->setTotalSteps(m_fileList.count());
     m_progressBar->setProgress(0);
-    m_progressBar->setEnabled(true);
+    m_progressBar->show();
 
-    RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance      = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance   = m_decodingSettingsBox->useAutoColorBalance();
-    rawDecodingSettings.RGBInterpolate4Colors   = m_decodingSettingsBox->useFourColor();
-    rawDecodingSettings.unclipColors            = m_decodingSettingsBox->unclipColor();
-    rawDecodingSettings.SuperCCDsecondarySensor = m_decodingSettingsBox->useSecondarySensor();
-    rawDecodingSettings.enableNoiseReduction    = m_decodingSettingsBox->useNoiseReduction();
-    rawDecodingSettings.brightness              = m_decodingSettingsBox->brightness();
-    rawDecodingSettings.NRSigmaDomain           = m_decodingSettingsBox->sigmaDomain();
-    rawDecodingSettings.NRSigmaRange            = m_decodingSettingsBox->sigmaRange();
-    rawDecodingSettings.RAWQuality              = m_decodingSettingsBox->quality();
-    rawDecodingSettings.outputFileFormat        = m_saveSettingsBox->fileFormat();
-    rawDecodingSettings.outputColorSpace        = m_decodingSettingsBox->outputColorSpace();
-    
-    m_thread->setRawDecodingSettings(rawDecodingSettings);
+    KDcrawIface::RawDecodingSettings rawDecodingSettings;
+    rawDecodingSettings.whiteBalance               = m_decodingSettingsBox->whiteBalance();
+    rawDecodingSettings.customWhiteBalance         = m_decodingSettingsBox->customWhiteBalance();
+    rawDecodingSettings.customWhiteBalanceGreen    = m_decodingSettingsBox->customWhiteBalanceGreen();
+    rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
+    rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
+    rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
+    rawDecodingSettings.enableNoiseReduction       = m_decodingSettingsBox->useNoiseReduction();
+    rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
+    rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
+    rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+    rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
+    rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
+    rawDecodingSettings.caMultiplier[1]            = m_decodingSettingsBox->caBlueMultiplier();
+    rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
+    rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
+
+    m_thread->setRawDecodingSettings(rawDecodingSettings, m_saveSettingsBox->fileFormat());
     processOne();
 }
 
@@ -343,7 +339,7 @@ void BatchDialog::slotUser2()
 void BatchDialog::slotAborted()
 {
     m_progressBar->setProgress(0);
-    m_progressBar->setEnabled(false);
+    m_progressBar->hide();
 }
 
 void BatchDialog::addItems(const QStringList& itemList)
@@ -352,16 +348,16 @@ void BatchDialog::addItems(const QStringList& itemList)
 
     switch(m_saveSettingsBox->fileFormat())
     {
-        case RawDecodingSettings::JPEG:
+        case SaveSettingsWidget::OUTPUT_JPEG:
             ext = "jpg";
             break;
-        case RawDecodingSettings::TIFF:
+        case SaveSettingsWidget::OUTPUT_TIFF:
             ext = "tif";
             break;
-        case RawDecodingSettings::PPM:
+        case SaveSettingsWidget::OUTPUT_PPM:
             ext = "ppm";
             break;
-        case RawDecodingSettings::PNG:
+        case SaveSettingsWidget::OUTPUT_PNG:
             ext = "png";
             break;
     }
@@ -400,16 +396,16 @@ void BatchDialog::slotSaveFormatChanged()
 
     switch(m_saveSettingsBox->fileFormat())
     {
-        case RawDecodingSettings::JPEG:
+        case SaveSettingsWidget::OUTPUT_JPEG:
             ext = "jpg";
             break;
-        case RawDecodingSettings::TIFF:
+        case SaveSettingsWidget::OUTPUT_TIFF:
             ext = "tif";
             break;
-        case RawDecodingSettings::PPM:
+        case SaveSettingsWidget::OUTPUT_PPM:
             ext = "ppm";
             break;
-        case RawDecodingSettings::PNG:
+        case SaveSettingsWidget::OUTPUT_PNG:
             ext = "png";
             break;
     }
